@@ -16,7 +16,6 @@ import asyncio
 import os
 from collections import defaultdict
 from pprint import pformat
-from typing import Any, Dict, Optional
 from urllib.parse import urlparse
 
 from aiohttp.client_exceptions import ClientConnectionError
@@ -135,7 +134,7 @@ class InvalidLimit(Exception):
 class SqliteQStore(SqliteStore):
     def _create_database(self):
         return SqliteQueueDatabase(
-            self.database_path, pragmas=(("foregign_keys", 1), ("secure_delete", 1))
+            self.database_path, pragmas=(("foreign_keys", 1), ("secure_delete", 1))
         )
 
     def close(self):
@@ -554,6 +553,7 @@ class PanClient(AsyncClient):
                 full_state=True,
                 since=next_batch,
                 loop_sleep_time=loop_sleep_time,
+                set_presence="offline",
             )
         )
         self.task = task
@@ -708,7 +708,6 @@ class PanClient(AsyncClient):
             for share in self.get_active_key_requests(
                 message.user_id, message.device_id
             ):
-
                 continued = True
 
                 if not self.continue_key_share(share):
@@ -810,8 +809,9 @@ class PanClient(AsyncClient):
 
         if not isinstance(event, MegolmEvent):
             logger.warn(
-                "Encrypted event is not a megolm event:"
-                "\n{}".format(pformat(event_dict))
+                "Encrypted event is not a megolm event:" "\n{}".format(
+                    pformat(event_dict)
+                )
             )
             return False
 
@@ -835,9 +835,9 @@ class PanClient(AsyncClient):
                 decrypted_event.source["content"]["url"] = decrypted_event.url
 
                 if decrypted_event.thumbnail_url:
-                    decrypted_event.source["content"]["info"][
-                        "thumbnail_url"
-                    ] = decrypted_event.thumbnail_url
+                    decrypted_event.source["content"]["info"]["thumbnail_url"] = (
+                        decrypted_event.thumbnail_url
+                    )
 
             event_dict.update(decrypted_event.source)
             event_dict["decrypted"] = True
