@@ -227,7 +227,8 @@ class ProxyDaemon:
 
         if ret:
             msg = (
-                f"Device {device.id} of user " f"{device.user_id} successfully verified."
+                f"Device {device.id} of user "
+                f"{device.user_id} successfully verified."
             )
             await client.send_update_device(device)
         else:
@@ -309,7 +310,6 @@ class ProxyDaemon:
                 DeviceUnblacklistMessage,
             ),
         ):
-
             device = client.device_store[message.user_id].get(message.device_id, None)
 
             if not device:
@@ -616,7 +616,9 @@ class ProxyDaemon:
                 await pan_client.close()
                 return
 
-        logger.info(f"Successfully started new background sync client for " f"{user_id}")
+        logger.info(
+            f"Successfully started new background sync client for " f"{user_id}"
+        )
 
         await self.send_ui_message(
             UpdateUsersMessage(self.name, user_id, pan_client.device_id)
@@ -733,7 +735,7 @@ class ProxyDaemon:
                     return decryption_method(body, ignore_failures=False)
                 except EncryptionError:
                     logger.info("Error decrypting sync, waiting for next pan " "sync")
-                    await client.synced.wait(),
+                    (await client.synced.wait(),)
                     logger.info("Pan synced, retrying decryption.")
 
         try:
@@ -793,6 +795,27 @@ class ProxyDaemon:
             body=await response.read(),
         )
 
+    async def createRoom(self, request):
+        try:
+            content = await request.json()
+        except (JSONDecodeError, ContentTypeError):
+            return self._not_json
+
+        invite = content.get("invite", ())
+        if invite:
+            access_token = self.get_access_token(request)
+
+            if not access_token:
+                return self._missing_token
+
+            client = await self._find_client(access_token)
+            if not client:
+                return self._unknown_token
+
+            client.users_for_key_query.update(invite)
+
+        return await self.forward_to_web(request)
+
     async def messages(self, request):
         access_token = self.get_access_token(request)
 
@@ -1273,7 +1296,9 @@ class ProxyDaemon:
         client = next(iter(self.pan_clients.values()))
 
         try:
-            response = await client.download(server_name, media_id, file_name)
+            response = await client.download(
+                server_name=server_name, media_id=media_id, filename=file_name
+            )
         except ClientConnectionError as e:
             raise e
 
